'use client';

import React, { useState } from 'react';
import { runMultiFileCodeWithOptionalTestData } from '@/actions/enhancedmultiFileRunner';

const TestPage = () => {
    const [code, setCode] = useState<string>('');
    const [language, setLanguage] = useState<string>('c');
    const [result, setResult] = useState<string>('');
    const [consoleOutput, setConsoleOutput] = useState<string>('');
    const [loading, setLoading] = useState<boolean>(false);
    const [resultFileContent, setResultFileContent] = useState<string>('');

    const handleRun = async () => {
        setLoading(true);
        setResult('');
        setConsoleOutput('');
        setResultFileContent('');

        const testFiles = [
            { name: 'input1.txt', content: '1 2 3' },
            { name: 'input2.txt', content: '4 5 6' },
        ];

        const expectedFiles = [
            { name: 'output1.txt', content: '6' },
            { name: 'output2.txt', content: '15' },
        ];

        const codeFile = {
            name: language === 'c' ? 'main.c' : language === 'python' ? 'script.py' : 'Main.java',
            content: code,
        };

        try {
            const result = await runMultiFileCodeWithOptionalTestData({
                files: [codeFile],
                language,
                testDataFiles: testFiles.map((file) => file.name),
                expectedAnswerFiles: expectedFiles.map((file) => file.name),
                resultOutputFile: 'result.txt',
            });

            if (result.error) {
                setConsoleOutput(result.error);
            } else {
                setConsoleOutput(result.output);
                if (result.comparisonResults) {
                    setResult(JSON.stringify(result.comparisonResults, null, 2));
                }

                // 设置 result.txt 的内容
                if (result.resultFileContent) {
                    setResultFileContent(result.resultFileContent);
                }
            }
        } catch (error) {
            setConsoleOutput(`Error: ${(error as Error).message}`);
        } finally {
            setLoading(false);
        }
    };

    return (
        <div style={{ padding: '20px', fontFamily: 'Arial, sans-serif' }}>
            <h1>Test Page</h1>
            <div style={{ marginBottom: '20px' }}>
                <label>
                    <strong>Language:</strong>
                    <select
                        value={language}
                        onChange={(e) => setLanguage(e.target.value)}
                        style={{ marginLeft: '10px' }}
                    >
                        <option value="c">C</option>
                        <option value="java">Java</option>
                        <option value="python">Python</option>
                    </select>
                </label>
            </div>
            <div style={{ marginBottom: '20px' }}>
                <label>
                    <strong>Code:</strong>
                    <textarea
                        value={code}
                        onChange={(e) => setCode(e.target.value)}
                        rows={10}
                        style={{ width: '100%', fontFamily: 'monospace', fontSize: '14px' }}
                    />
                </label>
            </div>
            <button
                onClick={handleRun}
                style={{
                    padding: '10px 20px',
                    background: 'blue',
                    color: 'white',
                    border: 'none',
                    borderRadius: '5px',
                    cursor: 'pointer',
                }}
                disabled={loading}
            >
                {loading ? 'Running...' : 'Run Code'}
            </button>
            <div style={{ marginTop: '20px' }}>
                <h2>Console Output</h2>
                <pre
                    style={{
                        background: '#f4f4f4',
                        padding: '10px',
                        border: '1px solid #ddd',
                        borderRadius: '5px',
                    }}
                >
                    {consoleOutput || 'No console output yet.'}
                </pre>
            </div>
            {result && (
                <div style={{ marginTop: '20px' }}>
                    <h2>Result</h2>
                    <pre
                        style={{
                            background: '#f4f4f4',
                            padding: '10px',
                            border: '1px solid #ddd',
                            borderRadius: '5px',
                        }}
                    >
                        {result || 'No results yet.'}
                    </pre>
                </div>
            )}
            {resultFileContent && (
                <div style={{ marginTop: '20px' }}>
                    <h2>Result File Content (result.txt)</h2>
                    <pre
                        style={{
                            background: '#f4f4f4',
                            padding: '10px',
                            border: '1px solid #ddd',
                            borderRadius: '5px',
                        }}
                    >
                        {resultFileContent || 'No result file content yet.'}
                    </pre>
                </div>
            )}
        </div>
    );
};

export default TestPage;
